---
title: BFCIComponents Contributing Guide
description: How to contribute BFCIComponents to the bfdocs library
---

# BFCIComponents Contributing Guide

## Component Specification

- Define inputs and configuration in your component spec.
- Document all variables and dependencies.
- Use reusable job templates for pipelines.

## Documentation

Each component needs proper documentation in the `docs/` directory:

- File name should match component name (e.g., `nodejs-build.md` for `nodejs-build.yml`)
- Include purpose, inputs, usage examples, and troubleshooting tips
- Follow the standard format shown in existing documentation

## Examples

Provide examples showing how to use your component in practical scenarios:

- Create examples in the `examples/` directory
- Examples should be complete, working `.gitlab-ci.yml` files
- Include comments explaining key configuration options

## Testing

Test your components thoroughly before contributing:

1. Create a test project with a `.gitlab-ci.yml` that uses your component
2. Run the pipeline to verify it works as expected
3. Test edge cases and different input configurations
4. Include a test report in your merge request

## Review Process

When submitting a merge request:

1. Explain the purpose and functionality of your component
2. Include documentation and examples
3. Reference any related issues
4. Ensure your changes pass CI/CD checks
5. Request review from at least one maintainer

## Versioning

When making changes to existing components:

- **PATCH:** Bug fixes, documentation improvements
- **MINOR:** New features, non-breaking changes
- **MAJOR:** Breaking changes to inputs or behavior

Update the `version` field in the component metadata accordingly.
