---
id: REORGANIZATION_PLAN
---
# BFDOCS Reorganization Plan

## Current State
- 570 markdown files in docs/
- Mix of:
  - Original bfdocs content (architecture, guides, etc.)
  - Copied content from other projects (BFAPI/, BFCLI/, etc.)
  - Consolidated documentation (move_consolidated/, demo_consolidated/)
  - Module-specific docs (drupal modules)

## Proposed Structure (Without Deleting Anything)

### 1. Core Documentation (Keep in docs/)
These are unique to bfdocs and should remain:
- `/architecture/` - System architecture documentation
- `/guides/` - Implementation guides
- `/development/` - Development standards
- `/operations/` - Operations documentation
- `/security/` - Security documentation
- `/testing/` - Testing strategies
- `/deployment/` - Deployment guides
- `/integration/` - Integration patterns
- `/migration/` - Migration guides
- `/planning/` - Roadmaps and planning docs

### 2. Project References (Create docs/projects/)
Instead of copying, create reference pages that link to actual project docs:
- `/projects/bfapi.md` - Links to ../bfapi/docs/
- `/projects/bfcli.md` - Links to ../bfcli/docs/
- `/projects/bfllm.md` - Links to ../bfllm/docs/
- etc.

### 3. Archived/Historical (Move to docs/archive/)
Older consolidated docs that provide historical context:
- `/archive/move_consolidated/`
- `/archive/demo_consolidated/`
- `/archive/platform/archived/`

### 4. Project-Specific Copies (Move to docs/reference-copies/)
Keep as reference but clearly mark as copies:
- `/reference-copies/BFAPI/`
- `/reference-copies/BFCLI/`
- `/reference-copies/components/`
- etc.

## Implementation Steps

1. **Create new structure directories**
2. **Create project reference pages** that link to live project docs
3. **Move duplicated content** to reference-copies/ (not delete)
4. **Update VuePress config** to reflect new structure
5. **Create automated sync** to pull latest from projects
6. **Setup GitLab Pages** deployment

## Benefits
- No data loss - everything is preserved
- Clear separation between bfdocs content and references
- Single source of truth for each project
- Easy to navigate structure
- GitLab Pages ready
