---
id: ai_swarm_intelligence-integration
---
# AI Swarm Intelligence Integration Guide

This document provides integration guidelines specific to the AI Swarm Intelligence module.

## Integration with Other Modules

The AI Swarm Intelligence module integrates with various other modules through standardized interfaces and patterns.

### Primary Integration Points

- **LLM Platform** - Integration via the `SwarmLlmBridge` service
- **Field ECA Bridge** - Integration through swarm-based field processing
- **Secure Drupal** - Security agent implementation
- **API Normalization** - Normalized API interfaces for swarm operations

## Implementation Details

### LLM Integration

The AI Swarm Intelligence module integrates with the LLM Platform through:

- `LlmAgent` implementation that delegates to the LLM Platform
- `SwarmLlmBridge` integration for model access
- Event subscribers for swarm coordination

### Field ECA Bridge Integration

Swarm-based field processing includes:

- Swarm-based field validation conditions
- Multi-agent field analysis actions
- Consensus-driven field recommendations

### Security Integration

The `SecurityAgent` implementation:

- Validates operations against security policies
- Provides audit logging for swarm operations
- Enforces rate limiting and resource constraints

## Shared Services

- `ai_swarm_intelligence.orchestrator` - Main orchestration service
- `ai_swarm_intelligence.emergence_engine` - Pattern detection engine
- `ai_swarm_intelligence.consensus_engine` - Multi-agent validation service

## Reference Documentation

For more information, see:

- [Integration Patterns](../integration/patterns)
- [Integration Code Quality Checklist](../integration/code-quality)
- [Service Naming Conventions](../integration/service-naming-conventions)
