---
id: components-bfcli-user
---
# BFCLI User Guide

This guide provides detailed instructions on how to use the Bluefly Command Line
Interface (BFCLI) effectively.

## Installation

### Global Installation

```bash
# Using npm
npm install -g bfcli

# Using yarn
yarn global add bfcli
```

### Local Installation

```bash
# Clone the repository
git clone https://gitlab.com/bluefly/BFCLI.git
cd BFCLI

# Install dependencies
npm install

# Link for local development
npm link
```

## Configuration

After installation, configure your BFCLI:

```bash
# Set API endpoint
bfcli config set apiUrl https://api.bluefly.io

# Set API key
bfcli config set apiKey your-api-key-here

# View current configuration
bfcli config list
```

## Command Groups

BFCLI organizes commands into logical groups:

### Model Commands

For working with AI models:

```bash
# List available models
bfcli model list

# Get model details
bfcli model get model-id

# Generate content with a model
bfcli model generate model-id "Your prompt here"
```

### Analyze Commands

For document analysis:

```bash
# Analyze an RFP document
bfcli analyze rfp path/to/document.pdf

# Extract specific information
bfcli analyze entities path/to/document.pdf

# View analysis history
bfcli analyze history
```

### Generate Commands

For content generation:

```bash
# Generate RFP response
bfcli generate response analysis-id output.md

# Generate specific section
bfcli generate section technical-approach

# List available templates
bfcli generate list-templates
```

### Dev Commands

For development workflows:

```bash
# Status across all projects
bfcli dev status-all

# Pull changes across all projects
bfcli dev pull-all

# Install dependencies across all projects
bfcli dev install-all
```

### Resource Commands

For resource management:

```bash
# List team members
bfcli resource list-team

# Create project quote
bfcli resource create-quote project-name requirements.json team.json labor.json
```

## Common Workflows

### RFP Response Workflow

1. Analyze the RFP document:

   ```bash
   bfcli analyze rfp rfp-document.pdf
   ```

2. Generate a response using the analysis:

   ```bash
   bfcli generate response analysis-id response.md
   ```

3. Export the response to the desired format:
   ```bash
   bfcli generate export response.md final-response.docx
   ```

### Development Workflow

```bash
# Check status of all projects
bfcli dev status-all

# Pull latest changes for all projects
bfcli dev pull-all

# Push changes for all projects
bfcli dev push-all
```

### GitLab Workflow

The workflow command group integrates with GitLab's CLI (glab) to provide a
streamlined workflow for managing projects in GitLab.

#### Prerequisites

Before using the workflow commands, ensure GitLab CLI is installed. BFCLI will
attempt to install it if not found.

```bash
# Set up workflow for all projects
bfcli workflow setup-all
```

#### Working with Merge Requests

```bash
# Create a merge request
bfcli workflow mr-create --project BFLLM --title "Feature: Add new model" --description "Adds support for a new model" --source feature-branch --target main

# List merge requests
bfcli workflow mr-list --project BFLLM --state opened

# Update a merge request
bfcli workflow mr-update 123 --project BFLLM --title "Updated title"

# Merge a merge request
bfcli workflow mr-merge 123 --project BFLLM --delete-branch

# Close a merge request
bfcli workflow mr-close 123 --project BFLLM
```

#### Working with Pipelines

```bash
# Run a pipeline
bfcli workflow pipeline-run --project BFLLM --branch main --variables '{"VARIABLE1":"value1","VARIABLE2":"value2"}'

# List pipelines
bfcli workflow pipeline-list --project BFLLM --status running
```

#### Working with Issues and Releases

```bash
# Create an issue
bfcli workflow issue-create --project BFLLM --title "Bug: Fix memory leak" --description "There's a memory leak in the model loading code"

# Create a release
bfcli workflow release-create --project BFLLM --tag v1.0.0 --name "Version 1.0.0" --description "Initial release"
```

## Advanced Usage

### Custom Output Formats

```

```
