---
id: components-bfllm-technical-CI-TROUBLESHOOTING
---
# CI/CD Troubleshooting Guide for BFLLM

This document provides solutions for common issues encountered during CI/CD processes for the BFLLM project.

## Common Issues and Solutions

### Package Installation Failures

If npm installation fails in the CI environment:

1. **Check Node.js Version Compatibility**

   - Ensure the Node.js version in the CI environment matches the one specified in `.nvmrc` or `package.json`
   - Current required version: Node.js 18.x or higher

2. **Private Package Access**

   - Verify GitLab CI has the correct token for accessing private packages
   - Check that `.npmrc` is properly configured with the GitLab registry

3. **Dependency Version Conflicts**
   - Look for peer dependency issues in the error logs
   - Check for conflicting versions between dependencies

### Test Failures

When tests pass locally but fail in CI:

1. **Environment Variable Configuration**

   - Ensure all required environment variables are set in the CI environment
   - Particularly check for `CLAUDE_API_KEY` and `BLUEFLY_API_KEY`

2. **Timing-Dependent Tests**

   - Tests that rely on timing might fail in CI due to different performance characteristics
   - Use proper test mocking and avoid hard-coded timeouts

3. **File Path Case Sensitivity**
   - Linux CI environments are case-sensitive for file paths, while macOS and Windows might not be
   - Ensure file imports use the exact case as the actual files

### Build Failures

Issues during the build process:

1. **TypeScript Compilation Errors**

   - Run `npm run typecheck` locally to catch errors before pushing
   - Check for incompatible type definitions in dependencies

2. **Out of Memory Errors**

   - For large builds, configure CI with additional memory
   - Add the `--max-old-space-size` parameter to Node.js

3. **Python Environment Issues**
   - When running hybrid Node.js/Python scripts, ensure Python dependencies are installed
   - Check for Python version compatibility (Python 3.9+ recommended)

## Debugging Tools

### Using CI Debug Logs

To enable verbose logging in CI:

1. In `.gitlab-ci.yml`, set the `CI_DEBUG_TRACE` variable to `"true"`
2. Add `set -x` at the beginning of bash script sections

### Local CI Testing

Test CI configuration locally:

```bash
# From the project root
./scripts/test-ci-locally.sh
```

This script simulates the CI environment on your local machine to catch issues before pushing.

### Troubleshooting Scripts

The project includes several troubleshooting scripts:

- `./scripts/fix-ci-issues.js` - Fixes common formatting and linting issues
- `./scripts/prepare-ci.sh` - Prepares the environment for CI
- `./scripts/register-model.py` - Troubleshoots model registry integration

## Model Registry Integration Issues

Common issues with MLflow and model registry integration:

1. **Authentication Failures**

   - Verify GitLab permissions for the CI pipeline
   - Check the `MLFLOW_TRACKING_URI` and related authentication variables

2. **Model Artifact Storage**

   - Ensure sufficient space in artifact storage
   - Verify path configurations in MLflow

3. **Version Conflicts**
   - When registering a new model version, check for existing version conflicts
   - Ensure semantic versioning is followed

## Contacting Support

If you encounter persistent CI issues:

1. Create a detailed issue in GitLab with logs and reproduction steps
2. Contact the DevOps team directly at devops@bluefly.io
3. For urgent issues, use the #ci-help channel in Slack
