---
title: BFUI
description: Documentation for BFUI
id: components-bfui
---

# Bluefly User Interface (BFUI)

## Important URLs

### Development URLs
- **Local Development Server:** `http://localhost:3000`
  - Start with `npm run dev`
  - Check `.env` file for actual port configuration
- **Storybook:** `http://localhost:6006`
  - Component documentation and testing
  - Start with `npm run storybook`
- **Component Playground:** `http://localhost:3000/playground`
  - Interactive component testing environment

### Repository & CI/CD
- **Repository:** `https://gitlab.com/bluefly-llm/BFUI`
  - Main development branch: `main`
  - Release branch: `release`
- **CI/CD Pipeline:** `https://gitlab.com/bluefly-llm/BFUI/-/pipelines`
- **Package Registry:** `https://gitlab.com/bluefly-llm/BFUI/container_registry`

### Documentation
- **Project Documentation (Local):** `http://localhost:8080/docs/components/bfui/`
  - Requires BFDOCS to be running (`cd ../BFDOCS && npm run docs:serve`)
- **Component Documentation:** 
  - Storybook (Local): `http://localhost:6006`
  - Published Storybook: `https://ui.bluefly.ai`
- **Technical Documentation:** Located in `/docs` folder in repository
  - Architecture diagrams
  - Component guidelines
  - Theme documentation
  - Development guides

### Related Services
- **BFAPI Integration:** `http://localhost:3001` (Backend API)
- **BFMCP Integration:** `http://localhost:3002` (Model Control Plane)
- **Analytics Dashboard:** `http://localhost:3000/analytics` (if configured)

### Environment-Specific URLs
- **Development:** `https://dev-ui.bluefly.ai`
- **Staging:** `https://staging-ui.bluefly.ai`
- **Production:** `https://ui.bluefly.ai`

### Testing & Quality
- **Test Runner:** `http://localhost:3000/tests`
  - Run with `npm test`
- **Coverage Report:** `http://localhost:3000/coverage`
  - Generate with `npm run test:coverage`
- **Performance Metrics:** `http://localhost:3000/metrics`
  - Available in development mode

## Quick Start
```bash
# Clone repository
git clone https://gitlab.com/bluefly-llm/BFUI.git

# Install dependencies
npm install

# Set up environment
cp .env.example .env

# Start development server
npm run dev

# Start Storybook (optional)
npm run storybook
```

For detailed setup instructions, see [Setup Guide](setup).

## Component Development
For information on creating new components, see [Component Development Guide](component-development).

# BFRFP Documentation

Welcome to the Bluefly RFP Response Platform documentation.

## Overview

BFRFP is a specialized application for automating and enhancing the RFP (Request for Proposal) response process.

## Getting Started

- [Installation](./getting-started/installation)
- [Configuration](./getting-started/configuration)
- [User Guide](./user/USER_GUIDE)

## API Reference

- [API Documentation](./api/API)

## Technical Documentation

- [AI Integration](./technical/AI_INTEGRATION)

## Quick Links

- [API Reference](./api/README)
- [Technical Documentation](./technical/README)
- [User Guide](./user-guide/README)

## Development

For development guidelines and contribution information, see the [Development Guide](../development/setup).
