---
id: demo_consolidated-QUICK_START
---
# 🚀 LLM Platform Quick Start

## **Most Critical: Get Ollama Working (5 minutes)**

Your platform is 90% ready. The most critical piece is getting **local AI** working with Ollama for complete data sovereignty.

### **Option 1: Automated Setup (Recommended)**

```bash
# Navigate to your Drupal site
cd ./DEMO

# Run the automated setup
ddev drush llm:setup-ollama

# Test that it works
ddev drush llm:test-ollama
```

### **Option 2: Manual Setup**

```bash
# 1. Install Ollama
curl -fsSL https://ollama.ai/install.sh | sh

# 2. Start Ollama service
ollama serve &

# 3. Pull essential models (this takes time - models are large)
ollama pull llama2:7b          # General purpose (3.8 GB)
ollama pull codellama:7b       # Code analysis (3.8 GB)  
ollama pull mistral:7b         # Summarization (4.1 GB)

# 4. Test it works
echo "Hello, say 'Ollama is working!'" | ollama run llama2:7b
```

### **Drupal Configuration**

1. Visit `/admin/config/ai/llm` in your Drupal site
2. Set **Default Processor** to "Ollama"
3. Set **Ollama Base URL** to `http://localhost:11434`
4. Save configuration

### **Test AI-Powered Content**

1. Create a new Article: `/node/add/article`
2. Use Field ECA Bridge for AI automation
3. Your content will be processed using **private local AI**

## **What You Get**

- ✅ **Complete Data Sovereignty** - No data leaves your server
- ✅ **Zero API Costs** - Unlimited AI processing for free
- ✅ **HIPAA/GDPR Ready** - Local processing means compliance
- ✅ **No Vendor Lock-in** - Open source models you control
- ✅ **Unlimited Usage** - Process as much content as you want

## **Available Models**

| Model | Size | Best For | Memory Needed |
|-------|------|----------|---------------|
| `llama2:7b` | 3.8 GB | General content | 8 GB RAM |
| `codellama:7b` | 3.8 GB | Code analysis | 8 GB RAM |
| `mistral:7b` | 4.1 GB | Summarization | 8 GB RAM |
| `llama2:13b` | 7.3 GB | Higher quality | 16 GB RAM |
| `llama2:70b` | 39 GB | Best quality | 64 GB RAM |

## **Useful Commands**

```bash
# List installed models
ddev drush llm:ollama-models

# Pull a new model
ddev drush llm:pull-model llama2:13b

# Check status
ddev drush llm:ollama-status

# Test AI processing
ddev drush llm:test-ollama
```

## **Next Steps**

1. **Create AI Workflows**: Use Field ECA Bridge to automate content processing
2. **Add More Models**: Install specialized models for different tasks
3. **Scale Up**: Add GPU acceleration for faster processing
4. **Integrate**: Connect with your existing content workflows

## **Hardware Requirements**

- **Minimum**: 8 GB RAM, 20 GB disk space
- **Recommended**: 16 GB RAM, 50 GB disk space
- **Optimal**: 32 GB RAM, GPU, 100 GB SSD

## **Troubleshooting**

### Ollama Not Starting
```bash
# Check if port is in use
lsof -i :11434

# Restart Ollama
pkill ollama
ollama serve
```

### Models Not Downloading
```bash
# Check disk space
df -h

# Check internet connection
curl -I https://ollama.ai
```

### Drupal Integration Issues
```bash
# Clear Drupal cache
ddev drush cr

# Check LLM module status
ddev drush pm:list | grep llm

# Test configuration
ddev drush llm:test-ollama
```

---

**🎯 Success Metric**: When `drush llm:test-ollama` returns "✅ Ollama is working correctly!", you have a complete private AI platform with unlimited processing capability and zero external dependencies.
