---
id: drupal_native_ai_nativeaijs-BLOCK_README
---
# Native AI.js Logs Dashboard Block

This block plugin provides a dashboard widget that displays a summary of recent Native AI.js logs and metrics. It's designed to be placed on the Drupal admin dashboard or any other page where you want to monitor AI operations.

## Features

- Displays the last 5 log entries (configurable)
- Shows statistics for the last 24 hours:
  - Total number of API calls
  - Average response time
  - Error rate percentage
  - Most frequently used model
  - Breakdown of operations by type
- Links to the full logs page for more detailed analysis
- Responsive design that works on all screen sizes
- Configurable caching for performance optimization
- Auto-refresh capability (optional)

## Installation

The block is automatically available when the `drupal_native_ai_nativeaijs` module is installed. No additional installation steps are required.

## Usage

1. Go to **Block Layout** at `/admin/structure/block`
2. Click **Place block** in the region where you want the dashboard to appear
3. Search for "Native AI.js Logs Dashboard" and click **Place block**
4. Configure the block settings:
   - **Title**: Customize the block title (optional)
   - **Number of log entries**: Set how many recent logs to display (1-20)
   - **Cache lifetime**: Set how long to cache the data (in seconds)
5. Configure display settings and visibility rules as needed
6. Click **Save block**

## Permissions

Users need the "View Native AI logs" permission to see the content of this block. If a user doesn't have this permission, the block will not be rendered for them.

## Integration with other modules

The logs dashboard block can be integrated with:

- **Dashboard module**: Place it on your admin dashboard for easy monitoring
- **Views**: Use the provided views integration to create custom log displays
- **Context**: Use context conditions to show the block in specific scenarios
- **Panels**: Add to a panel display for more advanced layout control

## Customization

### Template Customization

You can override the template by copying `native-aijs-logs-summary.html.twig` to your theme's templates directory and modifying it to match your design requirements.

### Style Customization

The block includes its own CSS, but you can override the styles in your theme's CSS. The main wrapper class is `.native-aijs-logs-summary`.

### JavaScript Customization

To enable auto-refresh functionality, add the following settings to your theme's JavaScript:

```javascript
drupalSettings.nativeAiJs = {
  autoRefresh: true,
  refreshInterval: 30000 // Refresh every 30 seconds
};
```

## Troubleshooting

### Block shows no data

- Verify that there are logs in the database
- Check that the user has the "View Native AI logs" permission
- Ensure the cache hasn't expired (try clearing the cache)

### Performance issues

- Increase the cache lifetime in the block settings
- Reduce the number of log entries displayed
- Ensure the database has proper indexes on the logs table

## Testing

The block plugin is fully tested with both unit and functional tests:

- Unit tests: `tests/src/Unit/Plugin/Block/NativeAiJsLogsBlockTest.php`
- Functional tests: `tests/src/Functional/NativeAiJsLogsBlockTest.php`

Run tests with:

```bash
./vendor/bin/phpunit modules/contrib/drupal_native_ai_nativeaijs/tests/src/Unit/Plugin/Block/NativeAiJsLogsBlockTest.php
./vendor/bin/phpunit modules/contrib/drupal_native_ai_nativeaijs/tests/src/Functional/NativeAiJsLogsBlockTest.php
```

## Related Components

- **Native AI Logs page**: Full logs display and filtering at `/admin/reports/native-ai-logs`
- **Native AI Log Detail page**: Detailed view of individual log entries
- **Native AI API**: For programmatic access to logs and metrics

## Technical Details

The block plugin uses:

- Dependency injection for database and date formatting services
- Proper caching with cache tags and contexts
- Responsive design principles
- JavaScript for enhanced interactivity
- Twig templates for themable output

## Extending

You can extend the functionality of this block by:

1. Implementing `hook_native_aijs_logs_stats_alter(&$stats)` to modify statistics
2. Implementing `hook_native_aijs_logs_data_alter(&$logs)` to modify log data
3. Implementing `hook_native_aijs_logs_dashboard_build_alter(&$build)` to modify the render array
