---
home: true
heroText: Bluefly LLM Platform
tagline: Enterprise-Ready AI Integration Platform for Drupal
heroImage: /logo.png
actions:
  - text: Get Started
    link: /getting-started/
    type: primary
  - text: View Projects
    link: /projects/
    type: secondary
features:
  - title: Production-Ready AI
    details: Enterprise-grade AI integration with proven Drupal patterns, 95/100 innovation score modules, and complete native integration.
  - title: Comprehensive Ecosystem
    details: 10+ integrated projects including API Gateway, LLM Services, CLI Tools, React Components, and 200+ Drupal modules.
  - title: Developer-First
    details: Complete CLI automation, GitLab CI/CD components, TypeScript SDKs, and extensive documentation for rapid development.
footer: Copyright © 2025 Bluefly | Built with VuePress
---

# Welcome to Bluefly LLM Platform Documentation

This is the comprehensive documentation hub for the Bluefly AI ecosystem - an enterprise-ready platform that brings production AI capabilities to Drupal and beyond.

## 🚀 Platform Overview

The Bluefly LLM Platform provides:

- **Native Drupal Integration**: Field API, Plugin systems, Views integration
- **Microservices Architecture**: Scalable, distributed AI services
- **Developer Tools**: CLI, SDKs, CI/CD components
- **Security & Compliance**: Enterprise-grade security framework
- **200+ Drupal Modules**: Comprehensive module ecosystem

## 📚 Documentation Structure

### Core Documentation
- [Architecture Overview](/architecture/) - System design and technical architecture
- [Getting Started Guide](/getting-started/) - Installation and quickstart
- [Development Standards](/development/) - Best practices and guidelines
- [API Reference](/api/) - Complete API documentation
- [Security Guide](/security/) - Security implementation and compliance

### Project Documentation
- [View All Projects](/projects/) - Documentation for all ecosystem projects
- [Core Services](/projects/#core-services) - BFAPI, BFLLM, BFMCP
- [Developer Tools](/projects/#developer-tools) - BFCLI, CI/CD Components
- [Frontend & SDKs](/projects/#frontend-sdks) - BFUI, Client libraries
- [Drupal Integration](/projects/#drupal-integration) - AI modules and recipes

### Guides & Tutorials
- [Implementation Guides](/guides/) - Step-by-step implementation guides
- [Integration Patterns](/integration/) - Service integration patterns
- [Migration Guide](/migration/) - Platform migration documentation
- [Testing Strategies](/testing/) - Comprehensive testing approach

## 🏗️ Platform Architecture

```mermaid
graph TB
    subgraph "Frontend Layer"
        UI[BFUI Components]
        CLI[BFCLI]
        SDK[BFAPI Client]
    end
    
    subgraph "API Gateway"
        BFAPI[BFAPI Gateway]
    end
    
    subgraph "Core Services"
        BFLLM[LLM Service]
        BFMCP[MCP Server]
        BFRFP[Content Gen]
    end
    
    subgraph "Integration Layer"
        DRUPAL[Drupal Modules]
        UNIFIED[Security Framework]
    end
    
    UI --> SDK
    CLI --> BFAPI
    SDK --> BFAPI
    BFAPI --> BFLLM
    BFAPI --> BFMCP
    BFAPI --> BFRFP
    DRUPAL --> BFAPI
    UNIFIED --> BFAPI
```

## 🔧 Quick Start

```bash
# Install the CLI
npm install -g @bluefly/cli

# Initialize a new project
bfcli init my-ai-project

# Deploy to Drupal
bfcli drupal:deploy

# Start development
bfcli dev
```

## 📊 Platform Statistics

- **Projects**: 10+ integrated services
- **Drupal Modules**: 200+ modules with 9 custom AI modules
- **Test Coverage**: 195 CI/CD test cases
- **Innovation Score**: 95/100 for core modules
- **Documentation**: 570+ documentation files

## 🔗 Important URLs

### GitLab Pages (Once Deployed)
- **Production Docs**: `https://bluefly.gitlab.io/ecosystem/bfdocs`
- **Project Repos**: `https://gitlab.bluefly.io/ecosystem`

### Local Development
- **VuePress Dev Server**: `http://localhost:8080` (run `npm run docs:dev`)
- **Built Documentation**: `./public/` (after `npm run docs:build`)

## 🤝 Contributing

We welcome contributions! See our [Contributing Guide](/development/contributing.html) for details on:
- Code standards
- Testing requirements
- Documentation guidelines
- Pull request process

## 📞 Support & Resources

- **GitLab**: [gitlab.bluefly.io/ecosystem](https://gitlab.bluefly.io/ecosystem)
- **Issues**: Report issues in individual project repositories
- **Discussion**: Join our community discussions
- **Enterprise Support**: Contact for enterprise support options
