---
id: migration-consolidation-plan
---
# Documentation Consolidation Plan

<!-- title: Documentation Consolidation Plan -->
<!-- description: Plan for consolidating scattered documentation files into the main documentation structure -->
<!-- lastUpdated: 2024-03-19 -->

## Overview

This document outlines the plan for consolidating scattered documentation files into the main `/bfdocs/docs` directory structure. The goal is to improve documentation organization, reduce duplication, and ensure consistent formatting.

## Current State

### Files to Consolidate

1. **CLAUDE.md Files**
   - `/CLAUDE.md` → `/bfdocs/docs/development/claude-integration.md`
   - `/./_CommonNPM/reelcode/CLAUDE.md` → `/bfdocs/docs/development/reelcode-integration.md`
   - `/_DrupalModules/CLAUDE.md` → `/bfdocs/docs/drupal/claude-integration.md`
   - `/_DrupalModules/drupal_migration_plus/docs/CLAUDE.md` → `/bfdocs/docs/drupal/migration-plus-integration.md`

2. **Implementation Plans**
   - `/bfapi/drupal_native_ai/INTEGRATION_PLAN.md` → `/bfdocs/docs/integration/drupal-native-ai.md`
   - `/bfapi/docs/NATIVE_AI_INTEGRATION_PLAN.md` → `/bfdocs/docs/integration/native-ai.md`
   - `/./_CommonNPM/reelcode/docs/implementation-plan/AI_ASSISTANT_INTEGRATION.md` → `/bfdocs/docs/integration/ai-assistant.md`
   - `/./_CommonNPM/reelcode/docs/implementation-plan/CICD_INTEGRATION_IMPLEMENTATION.md` → `/bfdocs/docs/development/cicd-implementation.md`

3. **Module Documentation**
   - `/_DrupalModules/drupal_native_ai/docs/AGENT_UI_COMPLETION.md` → `/bfdocs/docs/drupal/agent-ui.md`
   - `/_DrupalModules/drupal_native_ai/docs/AGENT_MANAGEMENT_SUMMARY.md` → `/bfdocs/docs/drupal/agent-management.md`
   - `/_DrupalModules/drupal_native_ai/docs/FEATURE_COMPARISON.md` → `/bfdocs/docs/drupal/feature-comparison.md`

4. **Technical Documentation**
   - `/bfrfp/docs/technical/CI-TROUBLESHOOTING.md` → `/bfdocs/docs/operations/ci-troubleshooting.md`
   - `/bfui/docs/technical/CI-TROUBLESHOOTING.md` → `/bfdocs/docs/operations/ui-ci-troubleshooting.md`

## Migration Steps

1. **Preparation**
   - Create backup of all files
   - Review content for duplication
   - Identify cross-references
   - Update internal links

2. **Content Organization**
   - Create new directory structure
   - Move files to new locations
   - Update frontmatter
   - Standardize formatting

3. **Content Updates**
   - Remove duplicates
   - Merge related content
   - Update cross-references
   - Add missing sections

4. **Validation**
   - Check all links
   - Verify formatting
   - Test navigation
   - Review search

## Directory Structure

```
bfdocs/docs/
├── development/
│   ├── claude-integration.md
│   ├── reelcode-integration.md
│   └── cicd-implementation.md
├── drupal/
│   ├── claude-integration.md
│   ├── migration-plus-integration.md
│   ├── agent-ui.md
│   ├── agent-management.md
│   └── feature-comparison.md
├── integration/
│   ├── drupal-native-ai.md
│   ├── native-ai.md
│   └── ai-assistant.md
└── operations/
    ├── ci-troubleshooting.md
    └── ui-ci-troubleshooting.md
```

## Migration Schedule

1. **Phase 1: Preparation (Day 1)**
   - Create backups
   - Review content
   - Update directory structure

2. **Phase 2: Migration (Day 2)**
   - Move files
   - Update frontmatter
   - Standardize formatting

3. **Phase 3: Content Updates (Day 3)**
   - Merge content
   - Update references
   - Add missing sections

4. **Phase 4: Validation (Day 4)**
   - Verify links
   - Test navigation
   - Final review

## Post-Migration Tasks

1. **Cleanup**
   - Remove old files
   - Update CI/CD
   - Update search index

2. **Documentation**
   - Update README
   - Add migration notes
   - Update contribution guide

3. **Monitoring**
   - Track broken links
   - Monitor search
   - Gather feedback

## Related Documentation

- [Documentation Guide](../development/documentation)
- [Contribution Guide](../development/contributing)
- [Style Guide](../development/style-guide) 
