---
id: modules-development-native_ai-AGENT_FIELD_INTEGRATION
---
# AI Agent Field Integration

This document describes the field integration capabilities for AI agents in the Drupal Native AI module.

## Overview

The Drupal Native AI module provides several field-level integrations that allow you to use AI agents directly in your content types. This enables powerful AI capabilities directly within your Drupal content workflow.

The field integration includes:

1. **Agent Execution Formatter**: Apply AI agents to existing text fields
2. **Agent Reference Field Type**: Store and display agent references in content
3. **Agent Selection Widget**: Select agents for use in content

## Agent Execution Formatter

The Agent Execution Formatter allows you to add AI agent capabilities to any existing text field. This formatter displays the field content and provides an interface for users to interact with an AI agent based on that content.

### Usage

1. Go to the "Manage Display" settings for your content type
2. For any text field, select "Agent Execution" as the formatter
3. Configure the formatter settings:
   - Select the agent to use
   - Configure the display options
   - Set up the interaction parameters

### Configuration Options

- **Agent**: Select which agent to use for this field
- **Prefix Text**: Text to prepend to the field value before sending to the agent
- **Show Field Value**: Whether to show the original field value
- **Show Execution Form**: Whether to show the form for interacting with the agent
- **Input Label**: The label for the input field
- **Button Label**: The text for the execute button
- **Placeholder**: Placeholder text for the input field
- **Initial Height**: Initial height of the input field in pixels

### Example Use Cases

- Add a Q&A interface to an article's body field
- Create interactive documentation with an AI assistant
- Add summarization capabilities to long-form content
- Enable content translation through AI

## Agent Reference Field Type

The Agent Reference Field Type allows you to store a reference to an AI agent directly in your content. This field type comes with its own formatters and widgets.

### Adding the Field

1. Go to the "Manage Fields" settings for your content type
2. Click "Add field"
3. Select "AI Agent Reference" as the field type
4. Configure the field settings:
   - Allowed capabilities: Limit which agents can be selected
   - Default options: Set default parameters for agent execution

### Field Settings

- **Allowed Capabilities**: Only show agents with these capabilities
- **Default Options**:
  - **Temperature**: Control randomness in responses
  - **Max Tokens**: Maximum response length

## Agent Reference Formatter

The Agent Reference Formatter displays a reference to an agent in various formats.

### Display Modes

- **Card**: A full card with agent details (name, description, capabilities)
- **Inline**: A compact inline display with the agent name
- **Badge**: A minimal badge showing only the agent name

### Configuration Options

- **Display Mode**: Card, Inline, or Badge
- **Show Description**: Whether to show the agent description
- **Show Capabilities**: Whether to show the agent capabilities
- **Show Execute Button**: Whether to show a button to execute the agent
- **Button Label**: The text for the execute button

## Agent Selection Widget

The Agent Selection Widget allows content editors to select an agent from those available in the system.

### Configuration Options

- **Include/Exclude Capabilities**: Filter agents based on their capabilities
- **Allow Execution**: Show a "Test" button for direct agent testing
- **Show Description**: Display agent descriptions in the selection widget
- **Show Capabilities**: Display agent capabilities in the selection widget

## Technical Implementation

The field integration is built on Drupal's Field API and uses the following components:

- **Field Formatters**: `AgentExecutionFormatter`, `AgentReferenceFormatter`
- **Field Widgets**: `AgentSelectionWidget`
- **Field Types**: `AgentReferenceItem`
- **Theme Functions**: Templates for displaying agents in fields

## Integration with Other Modules

The field integration works with:

- **Field UI**: For configuring fields in the admin UI
- **Field Group**: For organizing agent fields in groups
- **Layout Builder**: For placing agent fields in layouts
- **Views**: For listing and filtering content with agent fields

## Examples

### Adding a Smart Q&A to Articles

1. Add the "Agent Execution Formatter" to the Body field
2. Select an agent specialized in your content domain
3. Configure the formatter to show both the content and the execution form
4. Users can now ask questions about your article content

### Adding an AI Assistant to User Profiles

1. Add an "AI Agent Reference" field to the User entity
2. Configure the field to only allow agents with "chat" capability
3. Use the "Card" display mode to show the assistant prominently
4. Users can now have personal AI assistants on their profiles

### Creating AI-Enhanced Product Descriptions

1. Add the "Agent Execution Formatter" to the product description field
2. Configure it with a specialized e-commerce agent
3. Allow shoppers to ask questions about the product directly

## Best Practices

1. **Use Appropriate Agents**: Select agents that match the content's domain
2. **Set Clear Instructions**: Use prefix text to guide the agent's responses
3. **Consider Performance**: Agents require API calls, so use them judiciously
4. **Respect Privacy**: Be careful with sensitive information in fields
5. **Provide Context**: Always ensure agents have enough context to be helpful
