---
id: modules-development-native_ai-BENCHMARK_VISUALIZATION
---
# Benchmark Visualization Dashboard

The Benchmark Visualization Dashboard provides a comprehensive, interactive visualization of AI model performance metrics across different categories, allowing for intuitive comparison and analysis.

## Overview

This dashboard allows you to:

- Visualize performance, accuracy, efficiency, and cost metrics for AI models
- Compare multiple models side-by-side with different chart types
- Normalize values for fair comparison across metrics with different scales
- Filter models by provider and model type
- Filter metrics by category and importance
- Export benchmark data in CSV or JSON formats

## Usage

### Accessing the Dashboard

Navigate to **Admin > Configuration > AI > Drupal Native AI > Model Benchmarks > Benchmark Visualization**

### Dashboard Controls

The dashboard provides several controls to customize your visualization:

#### Filters

- **Model Type Filter**: Filter models by type (All, Commercial, Local)
- **Provider Filter**: Filter models by provider (All, OpenAI, Anthropic, etc.)
- **Metric Type Filter**: Filter metrics by category (All, Performance, Accuracy, etc.)

#### Visualization Controls

- **Visualization Type**: Choose between Bar Chart, Radar Chart, Polar Area, or Table View
- **Normalize Values**: Toggle to normalize all values to a 0-100 scale for easier comparison
- **Select All Models**: Quickly select or deselect all models
- **Export Data**: Export the current visualization data in CSV or JSON format

### Model Selection

The sidebar allows you to select which models to include in the visualization. Simply check or uncheck the models you want to compare.

### Metric Categories

Metrics are organized into categories:

- **Performance Metrics**: Speed, latency, and throughput measurements
- **Accuracy Metrics**: Benchmark scores, hallucination rates, factual accuracy
- **Efficiency Metrics**: Memory usage, power consumption
- **Cost Metrics**: Cost per million tokens, performance-per-dollar ratio

Each category can be expanded or collapsed to focus on specific areas of interest.

### Visualization Types

The dashboard supports different visualization types:

- **Bar Chart**: Traditional bar chart for direct comparison
- **Radar Chart**: Spider/radar chart showing multiple dimensions simultaneously
- **Polar Area**: Circular chart emphasizing area differences
- **Table View**: Tabular data display for precise values

## Data Normalization

The "Normalize Values" option makes it easier to compare metrics with different scales:

- All values are converted to a 0-100 scale
- For metrics where higher is better, higher values get higher scores
- For metrics where lower is better, lower values get higher scores
- This makes it immediately clear which models perform better across different metrics

## Adding Benchmark Data

There are several ways to add benchmark data to the system:

### Manual Entry

1. Go to **Admin > Configuration > AI > Drupal Native AI > Model Registry**
2. Select a model and edit its benchmark data

### API Integration

Use the Drupal Native AI API to programmatically update benchmark data:

```php
// Get the model comparison service
$comparison_service = \Drupal::service('drupal_native_ai.model_comparison');

// Update benchmark data for a model
$comparison_service->updateModelBenchmarks('model_id', [
  'tokens_per_second' => 150,
  'latency' => 250,
  'benchmark_scores' => 85,
  'memory_usage' => 4096,
]);
```

### Automated Benchmarking

Run automated benchmarks using the benchmark form:

1. Go to **Admin > Configuration > AI > Drupal Native AI > Model Benchmarks**
2. Select a model and benchmark scenario
3. Run the benchmark
4. Results will be automatically added to the model's benchmark data

## Technical Details

The benchmark visualization dashboard uses:

- Chart.js for interactive visualizations
- Dynamic data processing for normalization and comparison
- Responsive design that works well on all screen sizes
- JSON API for retrieving benchmark data

## Configuration

Configure the benchmark system at `/admin/config/ai/native/settings` with:

- API endpoint for Native AI.js
- Authentication credentials
- Synchronization settings
- Benchmark cache timeout

## Integration with Other Modules

The benchmark visualization dashboard can be extended by other modules:

- Add custom benchmark metrics
- Implement additional visualization types
- Add automated benchmark scenarios
- Extend the export functionality

## API Usage

You can programmatically access the benchmark visualization data:

```php
// Get the benchmark visualization controller
$controller = \Drupal::service('controller_resolver')
  ->getControllerFromDefinition('\Drupal\drupal_native_ai\Controller\BenchmarkVisualizationController::getChartData');

// Create a request with parameters
$request = new Request(['metrics' => ['tokens_per_second', 'latency'], 'models' => ['model1', 'model2']]);

// Get chart data
$chart_data = $controller($request)->getContent();

// Process the data
$data = json_decode($chart_data, TRUE);
```
