---
id: modules-development-native_ai-SETTINGS_FORM_UI
---
# Settings Form UI

The Drupal Native AI module includes a settings form UI that provides an intuitive and user-friendly interface for configuring the module. This document explains the features and how to use them.

## Overview

The settings form UI replaces the standard Drupal form with a modern, tabbed interface that organizes settings into logical groups. It includes visual indicators, interactive controls, and contextual help to make configuration easier and more intuitive.

## Key Features

### Dashboard Overview

The form begins with a dashboard overview that provides:

- **Status Cards**: Visual indicators for API connection status and provider availability
- **Quick Actions**: Buttons for common tasks like testing connection and synchronizing models

### Tabbed Navigation

Settings are organized into logical tabs:

1. **API Connection**: Settings for connecting to the Native AI.js API
2. **Providers**: Configuration for AI providers and provider priorities
3. **Models**: Settings for model comparison and benchmarking
4. **Streaming**: Configuration for streaming API responses
5. **AI Settings**: Core AI functionality settings
6. **Advanced**: Caching and debugging options

### Interactive Controls

The form includes several types of interactive controls:

- **Range Sliders**: Visual sliders with value displays for numeric settings
- **Visual Indicators**: Color-coded status indicators for connection status
- **Guided Inputs**: Range sliders with visual guides for optimal values

### Contextual Help

Help text is provided throughout the form to guide users:

- **Help Boxes**: Detailed information about specific settings
- **Range Guides**: Visual guides showing optimal ranges for numeric inputs
- **Descriptive Text**: Clear explanations of each setting's purpose

## Implementation Details

The UI form is implemented as a replacement for the standard settings form:

- `SettingsFormUI.php`: Extends `ConfigFormBase` and provides the UI interface
- `settings-form-ui.css`: Custom styling for the form
- `settings-form-ui.js`: JavaScript behaviors for interactive elements
- `admin-ui.css` and `admin-ui.js`: Base UI components and behaviors

Form replacement is done through `hook_form_alter()` in the module file.

## Screenshots

![Settings Form Dashboard](images/settings-form-dashboard.png)
*Dashboard view with status cards and quick actions*

![API Connection Tab](images/settings-form-api-connection.png)
*API Connection tab with form fields and help text*

![Providers Tab](images/settings-form-providers.png)
*Providers tab with provider priority table*

## Usage

1. Navigate to the module settings page at `/admin/config/services/drupal-native-ai`
2. The UI form will be displayed automatically
3. Navigate between tabs to configure different aspects of the module
4. Use the dashboard quick actions for common tasks
5. Save your configuration using the "Save Configuration" button at the bottom of the form

## Accessibility

The UI form maintains accessibility features:

- All form elements are properly labeled
- Focus states are clearly visible
- Color is not used as the only means of conveying information
- JavaScript enhancements have appropriate fallbacks
- ARIA attributes are used where appropriate

## Extension

The same UI patterns can be applied to other forms in the module:

- `AgentFormUI.php`: Already implements these patterns for the Agent form
- Other forms can use the same approach
- Shared UI components are defined in `admin-ui.css` and `admin-ui.js`

## Technical Notes

- Form state is maintained across tabs using JavaScript
- The form uses the standard Drupal Form API underneath
- All validation and submission handlers from the original form are preserved
- The UI form reads and writes to the same configuration as the original
