---
id: packages-development-bfapiclient
---
# BFAPIClient Documentation

TypeScript SDK for the Bluefly AI Platform API.

## Quick Start

```typescript
import { BFAPIClient } from '@bluefly/api-client';

const client = new BFAPIClient({
  baseURL: 'https://api.bluefly.ai',
  apiKey: process.env.BFAPI_KEY
});

// Use the client
const models = await client.models.list();
```

## Documentation

- [API Reference](api)
- [Configuration](configuration) 
- [Examples](examples)
- [Integration Guide](integration)
- [Error Handling](error-handling)
- [Resilience Patterns](resilience)
- [Resilient Caching](resilient-caching)
- [Changelog](changelog)

## Architecture

The bfapiclient serves as the TypeScript SDK for all Bluefly AI Platform services:

```
bfui → bfapiclient → bfapi
bfcli → bfapiclient → bfapi  
bfrfp → bfapiclient → bfapi
```

Key features:
- Type-safe API interactions
- Automatic authentication handling
- Built-in caching and retry logic
- Support for both REST and GraphQL endpoints- [SHARED_UTILITIES_MIGRATION.md](shared_utilities_migration)
